setwd ("/Users/yumotogenki/Desktop/Nat_com/data")

#Loading libraries
library(cluster) 
library(dplyr)
library(edgeR)
library(exactRankTests)
library(factoextra) 
library(ggbeeswarm)
library(ggplot2)
library(ggthemes)
library(gridExtra)
library(lubridate)
library(MASS)　
library(multcomp)
library(patchwork)
library(plotly)
library(scales)
library(survival)
library(survminer)　
library(tidyverse)

#Calculation of leaf growth rate
d <- read.csv("leaf_length.csv")
d1 <- d[as.Date(d$emergence.day) > as.Date("2018/2/1"),] #Select data for the period during which leaf length measurements were started.
d2 <- d1[d1$max_length >= 10,] #Select leaves with a maximum leaf length of at least 10 mm
d3 <- d2[d2$length > d2$max_length*0.9, ] #Only leaves that reach 90% of maximum leaf length are selected.

#Calculate the first day on which 90% of the maximum leaf length is reached for each leaf.
d3 %>%
  arrange(leaf_id) %>%
  group_by(leaf_id) %>% 
  arrange(as.Date(date)) %>%
  slice(1L) -> d4 

tibble() -> leaf_trait
leaf_trait <- d4[,1:3]
leaf_trait$growth_period <- as.numeric(as.Date(d4$date) - as.Date(d4$emergence.day))
leaf_trait$matured_leaf_length <- d4$length
leaf_trait$growth_rate <- leaf_trait$matured_leaf_length/leaf_trait$growth_period
#End of calculation of leaf growth rate


######

#k-means clustering
cohort <- read.csv("cohort_longevity.csv")
rownames(cohort) <- cohort$Emergence_date

cohort %>%
  dplyr::select(Median_growth_rate,L50) -> dfa
df1 <- na.omit(dfa)

#Determination of the k-number using the silhouette method.
#repeat k-means for 1:20 and extract silhouette:
sil <- rep(0, 20) 
for(i in 2:20){
  k1to20 <- kmeans(df1, centers = i, nstart = 25, iter.max = 20)
  ss <- silhouette(k1to20$cluster, dist(df1))
  sil[i] <- mean(ss[, 3])
}

# Plot the  average silhouette width
plot(1:20, sil, type = "b", pch = 19, xlab = "Number of clusters k", ylab="Average silhouette width")
abline(v = which.max(sil), lty = 2)

#k=2 is appropriate and k-means clustering is performed

k2 <- kmeans(df1, centers = 2, nstart = 25)
df1 %>%
  as_tibble() %>%
  mutate(cluster = k2$cluster,
         state = row.names(df1))
p2<-　fviz_cluster(k2, data = df1, geom="point") +
  theme(panel.background = element_blank(), panel.grid = element_blank()) +
  theme(panel.border = element_rect(fill = NA, size=1))
p2

#End of k-means clustering


######

# Decision tree analysis

df33 <- data.frame(class=as.factor(p$cohort),
                   Temperature=as.numeric(p$temp_33),
                   Light=as.numeric(p$light_33),
                   Photoperiod=as.numeric(p$photo_33))

class_model33 <- C5.0(df33[-1], df33$class)
summary(class_model33)

#End of Decision tree analysis


#####

#Parameter estimation of survival curves.
data <- read.csv("leaf_longevity.csv")
data$Emergence_date <- as.Date(data$Emergence_date)
data$Longevity <- as.numeric(data$Longevity)
df <- data.frame(sort(as.Date(unique(data$Emergence_date))))
colnames(df) <- ("date")


#Prepare an empty file to store the obtained parameters.
 table_parameta <- tibble()
  #The "for function" for determining parameters and creating plots for survival analysis curves.
  for (i in 1:nrow(df)) {
    dfi <- df[i, ] #Select the deployment date for the cohort to be analyzed
    dfi <- as.Date(dfi) #Convert a value to a date type
    datai <- data[data$Emergence_date %in% as.Date(dfi), ] #Extract cohorts for analysis
    
    datai %>%
      dplyr::select(Longevity, Status) -> lung2 #Extract data to be used for survival analysis curves
    fit <- survfit(Surv(Longevity, Status)~1, data=lung2) #Create Kaplan-Meier plots.
    fit2 <- survreg(formula = Surv(Longevity, Status) ~ 1, data = lung2, dist = "weibull") #Fitting a curve to Kaplan-Meier plots based on the Weibull distribution.
    
    tab <- data.frame(dfi, 1/fit2$scale, exp(coef(fit2)[1]), ((exp(coef(fit2)[1]))*(0.693147181)^(fit2$scale))) #Calculate α, β, and L50 from the fitting curve.
    colnames(tab) <- c("date", "a","b", "L50") #Give the column name.
    table_parameta <- rbind(table_parameta, tab) 
    
  }
#End of Parameter estimation of survival curves.
 
 
#####
 
#Statistical tests for manipulation experiments
d <- read.csv("manipulation_leaf_longevity.csv")
GS_shade <- d[d$Emergence_date %in% "2019/7/2",]
OW_shade <- d[d$Emergence_date %in% "2021/1/5",]
GS_sink <- d[d$Emergence_date %in% "2020/7/28",]
OW_sink <- d[d$Emergence_date %in% "2022/2/8",]


GS_shade1 <- survdiff(Surv(Longevity)~Treatment,data=GS_shade)
pchisq(GS_shade1$chisq, 1, lower.tail=FALSE)

OW_shade1 <- survdiff(Surv(Longevity)~Treatment,data=OW_shade)
pchisq(OW_shade1$chisq, 1, lower.tail=FALSE)
 
GS_sink1 <- survdiff(Surv(Longevity)~Treatment,data=GS_sink)
pchisq(GS_sink1$chisq, 1, lower.tail=FALSE)

OW_sink1 <- survdiff(Surv(Longevity)~Treatment,data=OW_sink)
pchisq(OW_sink1$chisq, 1, lower.tail=FALSE)

#End of Statistical tests for manipulation experiments

#edgeR on gene expression in manipulation experiments.
setwd("/data/edgeR/OW_shade")
library(tidyverse)
library(edgeR)
df <- read.csv("rawcnt.csv", row.names = 1)
d <- read.csv("log_rpm.csv", row.names = 1)
df$id <- row.names(df)
d$id <- row.names(d)

da <- d[d$av >= 1, ]

d1 <- df[df$id %in% da$id, ]
d1 <- d1[!(d1$id %in% "g24365.t1"), ] 
d1 %>%
  dplyr::select(1:6) -> d2 
d2$id <- row.names(d2) #Table of gene information
d1 %>%
  dplyr::select(7:50) -> counta #Table of raw count data for genes

colnames(counta)

counta %>%
  dplyr::select("OW_Exposed_1B","OW_Exposed_1C","OW_Exposed_1D","OW_Exposed_1E","OW_Exposed_1F","OW_Shaded_1B","OW_Shaded_1C","OW_Shaded_1D","OW_Shaded_1E","OW_Shaded_1F") -> count1 #Extraction of T1
counta %>%
  dplyr::select("OW_Exposed_2A","OW_Exposed_2C","OW_Exposed_2D","OW_Exposed_2E","OW_Exposed_2F","OW_Shaded_2A","OW_Shaded_2C","OW_Shaded_2D","OW_Shaded_2E","OW_Shaded_2F") -> count2 #Extraction of T2
counta %>%
  dplyr::select("OW_Exposed_3B","OW_Exposed_3C","OW_Exposed_3D","OW_Exposed_3E","OW_Exposed_3F","OW_Shaded_3B","OW_Shaded_3C","OW_Shaded_3D","OW_Shaded_3E","OW_Shaded_3F") -> count3 #Extraction of T3
counta %>%
  dplyr::select("OW_Exposed_4A","OW_Exposed_4C","OW_Exposed_4D","OW_Exposed_4E","OW_Exposed_4F","OW_Shaded_4A","OW_Shaded_4C","OW_Shaded_4D","OW_Shaded_4E","OW_Shaded_4F") -> count4 #Extraction of T4




#Create a design matrix for the full model.
treat1 = factor(c("Exposed","Exposed","Exposed","Exposed","Exposed","Shaded","Shaded","Shaded","Shaded","Shaded"))
plant1 = factor(c("2","3","4","5","6","2","3","4","5","6"))
design1 <- model.matrix(~treat1 + plant1)

treat2 = factor(c("Exposed","Exposed","Exposed","Exposed","Exposed","Shaded","Shaded","Shaded","Shaded","Shaded"))
plant2 = factor(c("1","3","4","5","6","1","3","4","5","6"))
design2 <- model.matrix(~treat2 + plant2)

treat3 = factor(c("Exposed","Exposed","Exposed","Exposed","Exposed","Shaded","Shaded","Shaded","Shaded","Shaded"))
plant3 = factor(c("2","3","4","5","6","2","3","4","5","6"))
design3 <- model.matrix(~treat3 + plant3)

treat4 = factor(c("Exposed","Exposed","Exposed","Exposed","Exposed","Shaded","Shaded","Shaded","Shaded","Shaded"))
plant4 = factor(c("1","3","4","5","6","1","3","4","5","6"))
design4 <- model.matrix(~treat4 + plant4)


#edgeR
#T1
d <- DGEList(counts = count1, group = treat1)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design1)
d <- estimateGLMTrendedDisp(d, design1)
d <- estimateGLMTagwiseDisp(d, design1)

fit <- glmFit(d, design1)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count1)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_1.csv", col.names = T, row.names = F)

#T2
d <- DGEList(counts = count2, group = treat2)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design2)
d <- estimateGLMTrendedDisp(d, design2)
d <- estimateGLMTagwiseDisp(d, design2)

fit <- glmFit(d, design2)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count2)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_2.csv", col.names = T, row.names = F)


#T3
d <- DGEList(counts = count3, group = treat3)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design3)
d <- estimateGLMTrendedDisp(d, design3)
d <- estimateGLMTagwiseDisp(d, design3)

fit <- glmFit(d, design3)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count3)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_3.csv", col.names = T, row.names = F)

#T4
d <- DGEList(counts = count4, group = treat4)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design4)
d <- estimateGLMTrendedDisp(d, design4)
d <- estimateGLMTagwiseDisp(d, design4)

fit <- glmFit(d, design4)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count4)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_4.csv", col.names = T, row.names = F)



T1 <- read.csv("edgeR_pair_1.csv")
row.names(T1) <- T1$p
T2 <- read.csv("edgeR_pair_2.csv")
row.names(T2) <- T2$p
T3 <- read.csv("edgeR_pair_3.csv")
row.names(T3) <- T3$p
T4 <- read.csv("edgeR_pair_4.csv")
row.names(T4) <- T4$p


T1a <- T1[T1$FDR < 0.0125, ]
T2a <- T2[T2$FDR < 0.0125, ]
T3a <- T3[T3$FDR < 0.0125, ]
T4a <- T4[T4$FDR < 0.0125, ]



T1a_plus <- T1a[T1a$logFC>0, ]
T2a_plus <- T2a[T2a$logFC>0, ]
T3a_plus <- T3a[T3a$logFC>0, ]
T4a_plus <- T4a[T4a$logFC>0, ]

T1a_minus <- T1a[T1a$logFC<0, ]
T2a_minus <- T2a[T2a$logFC<0, ]
T3a_minus <- T3a[T3a$logFC<0, ]
T4a_minus <- T4a[T4a$logFC<0, ]


d <- read.csv("log_rpm.csv", row.names = 1)
d$id <- row.names(d)
DEGs_plus <- d[d$id %in% T1a_plus$p|d$id %in% T2a_plus$p|d$id %in% T3a_plus$p|d$id %in% T4a_plus$p, ]
DEGs_minus <- d[d$id %in% T1a_minus$p|d$id %in% T2a_minus$p|d$id %in% T3a_minus$p|d$id %in% T4a_minus$p, ]

DEGs_plus1 <- DEGs_plus[!(DEGs_plus$id %in% DEGs_minus$id), ]
DEGs_minus1 <- DEGs_minus[!(DEGs_minus$id %in% DEGs_plus$id), ]

write.csv(DEGs_plus1, "DEGs_plus.csv")
write.csv(DEGs_minus1, "DEGs_minus.csv")




results <- cbind(T1$logFC,T1$FDR,T2$logFC,T2$FDR,T3$logFC,T3$FDR,T4$logFC,T4$FDR)
colnames(results) <- c("T1_FC", "T1_FDR", "T2_FC", "T2_FDR", "T3_FC", "T3_FDR", "T4_FC", "T4_FDR")
DEG_list2 <- cbind(T2[1:7], results)

write.csv(DEG_list2, "results.csv")


--------------------------------------------------------------------------------
setwd("/data/edgeR/GS_shade")
library(tidyverse)
library(edgeR)
df <- read.csv("rawcnt.csv", row.names = 1)
d <- read.csv("log_rpm.csv", row.names = 1)
df$id <- row.names(df)
d$id <- row.names(d)

da <- d[d$av >= 1, ]

d1 <- df[df$id %in% da$id, ]
d1 <- d1[!(d1$id %in% "g24365.t1"), ] 
d1 %>%
  dplyr::select(1:6) -> d2 
d2$id <- row.names(d2) #Table of gene information
d1 %>%
  dplyr::select(7:46) -> counta #Table of raw count data for genes

colnames(counta)

counta %>%
  dplyr::select("GS_Exposed_T1_B","GS_Exposed_T1_C","GS_Exposed_T1_D","GS_Exposed_T1_E","GS_Shaded_T1_B","GS_Shaded_T1_C","GS_Shaded_T1_D","GS_Shaded_T1_E") -> count1 #Extraction of T1
counta %>%
  dplyr::select("GS_Exposed_T2_B","GS_Exposed_T2_D","GS_Exposed_T2_E","GS_Exposed_T2_F","GS_Shaded_T2_B","GS_Shaded_T2_D","GS_Shaded_T2_E","GS_Shaded_T2_F") -> count2 #Extraction of T2
counta %>%
  dplyr::select("GS_Exposed_T3_B","GS_Exposed_T3_D","GS_Exposed_T3_E","GS_Exposed_T3_F","GS_Shaded_T3_B","GS_Shaded_T3_D","GS_Shaded_T3_E","GS_Shaded_T3_F") -> count3 #Extraction of T3
counta %>%
  dplyr::select("GS_Exposed_T4_B","GS_Exposed_T4_D","GS_Exposed_T4_E","GS_Exposed_T4_F","GS_Shaded_T4_B","GS_Shaded_T4_D","GS_Shaded_T4_E","GS_Shaded_T4_F") -> count4 #Extraction of T4
counta %>%
  dplyr::select("GS_Exposed_T5_C","GS_Exposed_T5_D","GS_Exposed_T5_E","GS_Exposed_T5_F","GS_Shaded_T5_C","GS_Shaded_T5_D","GS_Shaded_T5_E","GS_Shaded_T5_F") -> count5 #Extraction of T5




#Create a design matrix for the full model.
treat = factor(c("Exposed","Exposed","Exposed","Exposed","Shaded","Shaded","Shaded","Shaded"))
plant = factor(c("1","2","3","4","1","2","3","4"))
design <- model.matrix(~treat + plant)


#edgeR
#T1
d <- DGEList(counts = count1, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count1)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_1.csv", col.names = T, row.names = F)

#T2
d <- DGEList(counts = count2, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count2)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_2.csv", col.names = T, row.names = F)


#T3
d <- DGEList(counts = count3, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count3)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_3.csv", col.names = T, row.names = F)

#T4
d <- DGEList(counts = count4, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count4)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_4.csv", col.names = T, row.names = F)


#T5
d <- DGEList(counts = count5, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count5)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_5.csv", col.names = T, row.names = F)




T1 <- read.csv("edgeR_pair_1.csv")
row.names(T1) <- T1$p
T2 <- read.csv("edgeR_pair_2.csv")
row.names(T2) <- T2$p
T3 <- read.csv("edgeR_pair_3.csv")
row.names(T3) <- T3$p
T4 <- read.csv("edgeR_pair_4.csv")
row.names(T4) <- T4$p
T5 <- read.csv("edgeR_pair_5.csv")
row.names(T5) <- T5$p


T1a <- T1[T1$FDR < 0.01, ]
T2a <- T2[T2$FDR < 0.01, ]
T3a <- T3[T3$FDR < 0.01, ]
T4a <- T4[T4$FDR < 0.01, ]
T5a <- T5[T5$FDR < 0.01, ]



T1a_plus <- T1a[T1a$logFC>0, ]
T2a_plus <- T2a[T2a$logFC>0, ]
T3a_plus <- T3a[T3a$logFC>0, ]
T4a_plus <- T4a[T4a$logFC>0, ]
T5a_plus <- T5a[T5a$logFC>0, ]

T1a_minus <- T1a[T1a$logFC<0, ]
T2a_minus <- T2a[T2a$logFC<0, ]
T3a_minus <- T3a[T3a$logFC<0, ]
T4a_minus <- T4a[T4a$logFC<0, ]
T5a_minus <- T5a[T5a$logFC<0, ]


d <- read.csv("log_rpm.csv", row.names = 1)
d$id <- row.names(d)
DEGs_plus <- d[d$id %in% T1a_plus$p|d$id %in% T2a_plus$p|d$id %in% T3a_plus$p|d$id %in% T4a_plus$p|d$id %in% T5a_plus$p, ]
DEGs_minus <- d[d$id %in% T1a_minus$p|d$id %in% T2a_minus$p|d$id %in% T3a_minus$p|d$id %in% T4a_minus$p|d$id %in% T5a_minus$p, ]

DEGs_plus1 <- DEGs_plus[!(DEGs_plus$id %in% DEGs_minus$id), ]
DEGs_minus1 <- DEGs_minus[!(DEGs_minus$id %in% DEGs_plus$id), ]

write.csv(DEGs_plus1, "DEGs_plus.csv")
write.csv(DEGs_minus1, "DEGs_minus.csv")




results <- cbind(T1$logFC,T1$FDR,T2$logFC,T2$FDR,T3$logFC,T3$FDR,T4$logFC,T4$FDR,T5$logFC,T5$FDR)
colnames(results) <- c("T1_FC", "T1_FDR", "T2_FC", "T2_FDR", "T3_FC", "T3_FDR", "T4_FC", "T4_FDR", "T5_FC", "T5_FDR")
DEG_list2 <- cbind(T2[1:7], results)

write.csv(DEG_list2, "results.csv")

--------------------------------------------------------------------------------
setwd("/data/edgeR/GS_sink")
library(tidyverse)
library(edgeR)
df <- read.csv("rawcnt.csv", row.names = 1)
d <- read.csv("log_rpm.csv", row.names = 1)
df$id <- row.names(df)
d$id <- row.names(d)

da <- d[d$av >= 1, ]

d1 <- df[df$id %in% da$id, ]
d1 <- d1[!(d1$id %in% "g24365.t1"), ] 
d1 %>%
  dplyr::select(1:6) -> d2 
d2$id <- row.names(d2) #Table of gene information
d1 %>%
  dplyr::select(7:44) -> counta #Table of raw count data for genes

colnames(counta)

counta %>%
  dplyr::select("GS_Sink_minus_T2_A","GS_Sink_minus_T2_B","GS_Sink_minus_T2_C","GS_Sink_plus_T2_A","GS_Sink_plus_T2_B","GS_Sink_plus_T2_C") -> count2 #Extraction of T2
counta %>%
  dplyr::select("GS_Sink_minus_T3_A","GS_Sink_minus_T3_B","GS_Sink_minus_T3_C","GS_Sink_plus_T3_A","GS_Sink_plus_T3_B","GS_Sink_plus_T3_C") -> count3 #Extraction of T3
counta %>%
  dplyr::select("GS_Sink_minus_T4_A","GS_Sink_minus_T4_B","GS_Sink_plus_T4_A","GS_Sink_plus_T4_B") -> count4 #Extraction of T4
counta %>%
  dplyr::select("GS_Sink_minus_T5_A","GS_Sink_minus_T5_B","GS_Sink_minus_T5_C","GS_Sink_plus_T5_A","GS_Sink_plus_T5_B","GS_Sink_plus_T5_C") -> count5 #Extraction of T5
counta %>%
  dplyr::select("GS_Sink_minus_T6_A","GS_Sink_minus_T6_B","GS_Sink_plus_T6_A","GS_Sink_plus_T6_B") -> count6 #Extraction of T6
counta %>%
  dplyr::select("GS_Sink_minus_T7_A","GS_Sink_minus_T7_B","GS_Sink_plus_T7_A","GS_Sink_plus_T7_B") -> count7 #Extraction of T7



#Create a design matrix for the full model.
treat = factor(c("Minus","Minus","Minus","Plus","Plus","Plus"))
plant = factor(c("1","2","3","1","2","3"))
design <- model.matrix(~treat + plant)


treat6 = factor(c("Minus","Minus","Plus","Plus"))
plant6 = factor(c("1","2","1","2"))
design6 <- model.matrix(~treat6 + plant6)




#edgeR
#T2
d <- DGEList(counts = count2, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count2)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_2.csv", col.names = T, row.names = F)


#T3
d <- DGEList(counts = count3, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count3)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_3.csv", col.names = T, row.names = F)

#T4
d <- DGEList(counts = count4, group = treat6)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design6)
d <- estimateGLMTrendedDisp(d, design6)
d <- estimateGLMTagwiseDisp(d, design6)

fit <- glmFit(d, design6)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count4)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_4.csv", col.names = T, row.names = F)


#T5
d <- DGEList(counts = count5, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count5)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_5.csv", col.names = T, row.names = F)

#T6
d <- DGEList(counts = count6, group = treat6)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design6)
d <- estimateGLMTrendedDisp(d, design6)
d <- estimateGLMTagwiseDisp(d, design6)

fit <- glmFit(d, design6)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count5)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_6.csv", col.names = T, row.names = F)

#T7
d <- DGEList(counts = count7, group = treat6)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design6)
d <- estimateGLMTrendedDisp(d, design6)
d <- estimateGLMTagwiseDisp(d, design6)

fit <- glmFit(d, design6)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count5)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_7.csv", col.names = T, row.names = F)


T2 <- read.csv("edgeR_pair_2.csv")
row.names(T2) <- T2$p
T3 <- read.csv("edgeR_pair_3.csv")
row.names(T3) <- T3$p
T4 <- read.csv("edgeR_pair_4.csv")
row.names(T4) <- T4$p
T5 <- read.csv("edgeR_pair_5.csv")
row.names(T5) <- T5$p
T6 <- read.csv("edgeR_pair_6.csv")
row.names(T6) <- T6$p
T7 <- read.csv("edgeR_pair_7.csv")
row.names(T7) <- T7$p



T2a <- T2[T2$FDR < 0.00833, ]
T3a <- T3[T3$FDR < 0.00833, ]
T4a <- T4[T4$FDR < 0.00833, ]
T5a <- T5[T5$FDR < 0.00833, ]
T6a <- T6[T6$FDR < 0.00833, ]
T7a <- T7[T7$FDR < 0.00833, ]



T2a_plus <- T2a[T2a$logFC>0, ]
T3a_plus <- T3a[T3a$logFC>0, ]
T4a_plus <- T4a[T4a$logFC>0, ]
T5a_plus <- T5a[T5a$logFC>0, ]
T6a_plus <- T6a[T6a$logFC>0, ]
T7a_plus <- T7a[T7a$logFC>0, ]

T5a_minus <- T5a[T5a$logFC<0, ]
T2a_minus <- T2a[T2a$logFC<0, ]
T3a_minus <- T3a[T3a$logFC<0, ]
T4a_minus <- T4a[T4a$logFC<0, ]
T6a_minus <- T6a[T6a$logFC<0, ]
T7a_minus <- T7a[T7a$logFC<0, ]


d <- read.csv("log_rpm.csv", row.names = 1)
d$id <- row.names(d)
DEGs_plus <- d[d$id %in% T5a_plus$p|d$id %in% T2a_plus$p|d$id %in% T3a_plus$p|d$id %in% T4a_plus$p|d$id %in% T6a_plus$p|d$id %in% T7a_plus$p, ]
DEGs_minus <- d[d$id %in% T5a_minus$p|d$id %in% T2a_minus$p|d$id %in% T3a_minus$p|d$id %in% T4a_minus$p|d$id %in% T6a_minus$p|d$id %in% T7a_minus$p, ]

DEGs_plus1 <- DEGs_plus[!(DEGs_plus$id %in% DEGs_minus$id), ]
DEGs_minus1 <- DEGs_minus[!(DEGs_minus$id %in% DEGs_plus$id), ]

write.csv(DEGs_plus1, "DEGs_plus.csv")
write.csv(DEGs_minus1, "DEGs_minus.csv")




results <- cbind(T2$logFC,T2$FDR,T3$logFC,T3$FDR,T4$logFC,T4$FDR,T5$logFC,T5$FDR,T6$logFC,T6$FDR,T7$logFC,T7$FDR)
colnames(results) <- c("T2_FC", "T2_FDR", "T3_FC", "T3_FDR", "T4_FC", "T4_FDR","T5_FC", "T5_FDR", "T6_FC", "T6_FDR","T7_FC", "T7_FDR")
DEG_list2 <- cbind(T2[1:7], results)

write.csv(DEG_list2, "results.csv")

--------------------------------------------------------------------------------
  setwd("/data/edgeR/OW_sink")
library(tidyverse)
library(edgeR)
df <- read.csv("rawcnt.csv", row.names = 1)
d <- read.csv("log_rpm.csv", row.names = 1)
df$id <- row.names(df)
d$id <- row.names(d)

da <- d[d$av >= 1, ]

d1 <- df[df$id %in% da$id, ]
d1 <- d1[!(d1$id %in% "g24365.t1"), ] 
d1 %>%
  dplyr::select(1:6) -> d2 
d2$id <- row.names(d2) #Table of gene information
d1 %>%
  dplyr::select(9:57) -> counta #Table of raw count data for genes

colnames(counta)

counta %>%
  dplyr::select("OW_Sink_minus_T2_A","OW_Sink_minus_T2_B","OW_Sink_minus_T2_C","OW_Sink_plus_T2_A","OW_Sink_plus_T2_B","OW_Sink_plus_T2_C") -> count2 #Extraction of T2
counta %>%
  dplyr::select("OW_Sink_minus_T3_A","OW_Sink_minus_T3_B","OW_Sink_minus_T3_C","OW_Sink_minus_T3_D","OW_Sink_plus_T3_A","OW_Sink_plus_T3_B","OW_Sink_plus_T3_C","OW_Sink_plus_T3_D") -> count3 #Extraction of T3
counta %>%
  dplyr::select("OW_Sink_minus_T4_A","OW_Sink_minus_T4_B","OW_Sink_minus_T4_C","OW_Sink_minus_T4_D","OW_Sink_plus_T4_A","OW_Sink_plus_T4_B","OW_Sink_plus_T4_C","OW_Sink_plus_T4_D") -> count4 #Extraction of T4
counta %>%
  dplyr::select("OW_Sink_minus_T5_A","OW_Sink_minus_T5_B","OW_Sink_minus_T5_C","OW_Sink_minus_T5_D","OW_Sink_plus_T5_A","OW_Sink_plus_T5_B","OW_Sink_plus_T5_C","OW_Sink_plus_T5_D") -> count5 #Extraction of T5



#Create a design matrix for the full model.
treat = factor(c("Minus","Minus","Minus","Minus","Plus","Plus","Plus","Plus"))
plant = factor(c("1","2","3","4","1","2","3","4"))
design <- model.matrix(~treat + plant)

treat2 = factor(c("Minus","Minus","Minus","Plus","Plus","Plus"))
plant2 = factor(c("1","2","3","1","2","3"))
design2 <- model.matrix(~treat2 + plant2)




#edgeR
#T2
d <- DGEList(counts = count2, group = treat2)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design2)
d <- estimateGLMTrendedDisp(d, design2)
d <- estimateGLMTagwiseDisp(d, design2)

fit <- glmFit(d, design2)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count2)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_2.csv", col.names = T, row.names = F)


#T3
d <- DGEList(counts = count3, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count3)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_3.csv", col.names = T, row.names = F)

#T4
d <- DGEList(counts = count4, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count4)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_4.csv", col.names = T, row.names = F)


#T5
d <- DGEList(counts = count5, group = treat)
d <- calcNormFactors(d)
d <- estimateGLMCommonDisp(d, design)
d <- estimateGLMTrendedDisp(d, design)
d <- estimateGLMTagwiseDisp(d, design)

fit <- glmFit(d, design)
lrt <- glmLRT(fit, coef = 2)
topTags(lrt)
#Formatting the results of edgeR
table <- as.data.frame(topTags(lrt, n = nrow(count5)))
p <- row.names(table)
cbind(p, table) -> table1
table1 <- table1[order(table1$p), ]
table2 <- cbind(d2,table1)
#Output a table of results
write.csv(table2, file = "edgeR_pair_5.csv", col.names = T, row.names = F)


T2 <- read.csv("edgeR_pair_2.csv")
row.names(T2) <- T2$p
T3 <- read.csv("edgeR_pair_3.csv")
row.names(T3) <- T3$p
T4 <- read.csv("edgeR_pair_4.csv")
row.names(T4) <- T4$p
T5 <- read.csv("edgeR_pair_5.csv")
row.names(T5) <- T5$p


T2a <- T2[T2$FDR < 0.0125, ]
T3a <- T3[T3$FDR < 0.0125, ]
T4a <- T4[T4$FDR < 0.0125, ]
T5a <- T5[T5$FDR < 0.0125, ]




T2a_plus <- T2a[T2a$logFC>0, ]
T3a_plus <- T3a[T3a$logFC>0, ]
T4a_plus <- T4a[T4a$logFC>0, ]
T5a_plus <- T5a[T5a$logFC>0, ]

T5a_minus <- T5a[T5a$logFC<0, ]
T2a_minus <- T2a[T2a$logFC<0, ]
T3a_minus <- T3a[T3a$logFC<0, ]
T4a_minus <- T4a[T4a$logFC<0, ]


d <- read.csv("log_rpm.csv", row.names = 1)
d$id <- row.names(d)
DEGs_plus <- d[d$id %in% T5a_plus$p|d$id %in% T2a_plus$p|d$id %in% T3a_plus$p|d$id %in% T4a_plus$p, ]
DEGs_minus <- d[d$id %in% T5a_minus$p|d$id %in% T2a_minus$p|d$id %in% T3a_minus$p|d$id %in% T4a_minus$p, ]

DEGs_plus1 <- DEGs_plus[!(DEGs_plus$id %in% DEGs_minus$id), ]
DEGs_minus1 <- DEGs_minus[!(DEGs_minus$id %in% DEGs_plus$id), ]

write.csv(DEGs_plus1, "DEGs_plus.csv")
write.csv(DEGs_minus1, "DEGs_minus.csv")




results <- cbind(T2$logFC,T2$FDR,T3$logFC,T3$FDR,T4$logFC,T4$FDR,T5$logFC,T5$FDR)
colnames(results) <- c("T2_FC", "T2_FDR", "T3_FC", "T3_FDR", "T4_FC", "T4_FDR","T5_FC", "T5_FDR" )
DEG_list2 <- cbind(T2[1:7], results)

write.csv(DEG_list2, "results.csv")


#End of edgeR on gene expression in manipulation experiments.


  


